'use strict';

var tslib_es6 = require('../__helpers/tslib/tslib.es6.js');
var localForage = require('localforage');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var localForage__default = /*#__PURE__*/_interopDefaultLegacy(localForage);

var LocalForageDatabaseEngine = /** @class */ (function () {
    /**
     * Constructor
     */
    function LocalForageDatabaseEngine(name, storeName) {
        /**
         * Prefix key
         */
        this.prefixKey = "";
        this.storage = localForage__default["default"].createInstance({
            name: name,
            storeName: storeName,
        });
    }
    /**
     * Set data into storage engine
     * @param {string} key
     * @param {value} value
     */
    LocalForageDatabaseEngine.prototype.set = function (key, value) {
        return this.storage.setItem(this.getKey(key), value);
    };
    /**
     * Get vale from storage engine
     *
     * @param   {string} key
     * @param   {CacheData} cacheData
     * @returns {any}
     */
    LocalForageDatabaseEngine.prototype.get = function (key, cacheData) {
        return this.dataFetcher(key, function (value) { return value; }, cacheData);
    };
    /**
     * Remove key from storage
     *
     * @param  {string} key
     */
    LocalForageDatabaseEngine.prototype.remove = function (key) {
        return this.storage.removeItem(this.getKey(key));
    };
    /**
     * Get a proper key
     *
     * @param {string} key
     * @returns {string}
     */
    LocalForageDatabaseEngine.prototype.getKey = function (key) {
        return (this.getPrefixKey() || "") + key;
    };
    /**
     * Clear all data in database
     */
    LocalForageDatabaseEngine.prototype.flush = function () {
        this.storage.clear();
    };
    /**
     * Clear all data in database
     */
    LocalForageDatabaseEngine.prototype.clear = function () {
        this.storage.clear();
    };
    /**
     * Get prefix key
     *
     * @returns {string}
     */
    LocalForageDatabaseEngine.prototype.getPrefixKey = function () {
        return this.prefixKey;
    };
    /**
     * Set prefix key
     *
     * @returns {DatabaseDriverInterface}
     */
    LocalForageDatabaseEngine.prototype.setPrefixKey = function (prefixKey) {
        this.prefixKey = prefixKey;
        return this;
    };
    /**
     * Data fetcher method to get the value from the database
     * If the value doesn't exists and the cacheData method is passed,
     * then grab it and store the data then return it
     */
    LocalForageDatabaseEngine.prototype.dataFetcher = function (key, valueHandler, cacheData) {
        var _this = this;
        if (cacheData === void 0) { cacheData = null; }
        return new Promise(function (resolve, reject) {
            _this.storage
                .getItem(_this.getKey(key))
                .then(function (value) { return tslib_es6.__awaiter(_this, void 0, void 0, function () {
                return tslib_es6.__generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(!value && cacheData)) return [3 /*break*/, 2];
                            return [4 /*yield*/, cacheData()];
                        case 1:
                            value = _a.sent();
                            this.set(key, value);
                            _a.label = 2;
                        case 2:
                            resolve(valueHandler(value));
                            return [2 /*return*/];
                    }
                });
            }); })
                .catch(reject);
        });
    };
    return LocalForageDatabaseEngine;
}());

module.exports = LocalForageDatabaseEngine;
